@@ -6,7 +6,7 @@ Applify - Write object oriented scripts with ease
 
 =head1 VERSION
 
-0.0501
+0.06
 
 =head1 DESCRIPTION
 
@@ -92,7 +92,7 @@ use constant SUB_NAME_IS_AVAILABLE
      : eval 'use Sub::Name; 1'        ? 1
      :                                  0;
 
-our $VERSION = eval '0.0501';
+our $VERSION = '0.06';
 our $PERLDOC = 'perldoc';
 my $ANON = 1;
 
@@ -383,7 +383,7 @@ sub _generate_application_class {
 
             for my $name (keys %$ns) {
                 $self->{skip_subs}{$name} and next;
-                my $code = *{$ns->{$name}}{CODE} or next;
+                my $code = eval { *{$ns->{$name}}{CODE} } or next;
                 my $fqn = join '::', $application_class, $name;
                 __new_sub $fqn => $code;
                 delete $ns->{$name}; # may be a bit too destructive?
